<?php
assert_options(ASSERT_BAIL, 1);

include("btrievePhp.php");

$min_x = 0;
$max_x = 255;
$btrieveFileName = "squaresAndSquareRoots.btr";
$recordFormatPack = "Cvd";
$recordFormatUnpack = "Cx/vxSquared/dxSquareRoot";
$recordLength = 11;
$keyFormat = "C";

parse_str(implode('&', array_slice($argv, 1)), $_POST);

$integerValue = $_POST['x'];

if ($integerValue == "")
{
	exit("'x' must be a uint8 value.\n");
}

if (($integerValue < $min_x) or ($integerValue > $max_x))
{
	exit("'x' must be a uint8 value.\n");
}

$btrieveClient = new BtrieveClient();
assert($btrieveClient != NULL);

$btrieveFileAttributes = new BtrieveFileAttributes();
assert($btrieveFileAttributes != NULL);

$rc = $btrieveFileAttributes->SetFixedRecordLength($recordLength);
assert($rc == Btrieve::STATUS_CODE_NO_ERROR, "Error: BtrieveFileAttributes::SetLogicalFixedRecordLength():" . $rc . ":" . Btrieve::StatusCodeToString($rc) . "\n");

$rc = $btrieveClient->FileCreate($btrieveFileAttributes, $btrieveFileName, Btrieve::CREATE_MODE_OVERWRITE);
assert($rc == Btrieve::STATUS_CODE_NO_ERROR, "Error: BtrieveClient::FileCreate():" . $rc . ":" . Btrieve::StatusCodeToString($rc) . "\n");

$btrieveFile = new BtrieveFile();
assert($btrieveFile != NULL);

$rc = $btrieveClient->FileOpen($btrieveFile, $btrieveFileName, "", Btrieve::OPEN_MODE_NORMAL);
assert($rc == Btrieve::STATUS_CODE_NO_ERROR, "Error: BtrieveClient::FileOpen():" . $rc . ":" . Btrieve::StatusCodeToString($rc) . "\n");

# For all the values of x.
for ($i = $min_x; $i <= $max_x; $i++) 
{
	$record = pack($recordFormatPack, $i, $i * $i, sqrt((double)$i));

   $rc = $btrieveFile->RecordCreate($record);
   assert($rc == Btrieve::STATUS_CODE_NO_ERROR, "Error: BtrieveFile::RecordCreate():" . $rc . ":" . Btrieve::StatusCodeToString($rc) . "\n");
}

$btrieveKeySegment = new BtrieveKeySegment();
assert($btrieveKeySegment != NULL);

$rc = $btrieveKeySegment->SetField(0, 1, Btrieve::DATA_TYPE_INTEGER);
assert($rc == Btrieve::STATUS_CODE_NO_ERROR, "Error: BtrieveKeySegment::SetField():" . $rc . ":" . Btrieve::StatusCodeToString($rc) . "\n");

$btrieveIndexAttributes = new BtrieveIndexAttributes();
assert($btrieveIndexAttributes != NULL);

$rc = $btrieveIndexAttributes->AddKeySegment($btrieveKeySegment);
assert($rc == Btrieve::STATUS_CODE_NO_ERROR, "Error: BtrieveIndexAttributes::AddKeySegment():" . $rc . ":" . Btrieve::StatusCodeToString($rc) . "\n");

$rc = $btrieveFile->IndexCreate($btrieveIndexAttributes, Btrieve::INDEX_1);
assert($rc == Btrieve::STATUS_CODE_NO_ERROR, "Error: BtrieveFile::IndexCreate():" . $rc . ":" . Btrieve::StatusCodeToString($rc) . "\n");

$record = pack($recordFormatPack, 0, 0, 0);
$key = pack($keyFormat, $integerValue);

$rc = $btrieveFile->RecordRetrieve(Btrieve::COMPARISON_EQUAL, Btrieve::INDEX_1, $key, $record);
assert($rc == $recordLength, "Error: BtrieveFile::RecordRetrieve():" . $rc . ":" . Btrieve::StatusCodeToString($btrieveFile->GetLastStatusCode()) . "\n");

# print record
$array = unpack($recordFormatUnpack, $record);
echo json_encode($array) . "\n";

$rc = $btrieveClient->FileClose($btrieveFile);
assert($rc == Btrieve::STATUS_CODE_NO_ERROR, "Error: BtrieveClient::FileClose():" . $rc . ":" . Btrieve::StatusCodeToString($rc) . "\n");

$rc = $btrieveClient->FileDelete($btrieveFileName);
assert($rc == Btrieve::STATUS_CODE_NO_ERROR, "Error: BtrieveClient::FileDelete():" . $rc . ":" . Btrieve::StatusCodeToString($rc) . "\n");
?>
